@use "page";

.ct-check-circle {
  color: var(--pf-v5-global--success-color--100);
}

.ct-info-circle {
  color: var(--pf-v5-global--info-color--100);
}

.ct-exclamation-triangle {
  color: var(--pf-v5-global--warning-color--100);
}

.ct-exclamation-circle {
  color: var(--pf-v5-global--danger-color--100);
}
