@import "global-variables";
@import "@patternfly/patternfly/utilities/Text/text.scss";

.system-information-failed-login-warning-icon {
  color: var(--pf-v5-global--warning-color--100);
}

.system-information-failed-login-warning {
  color: var(--pf-v5-global--warning-color--200);
  font-weight: bold;
}

.system-information-failed-login-danger-icon {
  color: var(--pf-v5-global--danger-color--100);
}

.system-information-failed-login-danger {
  color: var(--pf-v5-global--danger-color--200);
  font-weight: bold;
}

.system-information-last-login-icon {
  color: var(--pf-v5-global--Color--200);
}

.ct-grey-text {
  color: var(--pf-v5-global--Color--200);
}
